spannertools.move_spanners_from_component_to_children_of_component
==================================================================

.. autofunction:: abjad.tools.spannertools.move_spanners_from_component_to_children_of_component.move_spanners_from_component_to_children_of_component
